Method: Buildium::BillPaymentLinePostMessage#initialize
- Defined in:
- lib/buildium-ruby/models/bill_payment_line_post_message.rb
#initialize(attributes = {}) ⇒ BillPaymentLinePostMessage
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/buildium-ruby/models/bill_payment_line_post_message.rb', line 53 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Buildium::BillPaymentLinePostMessage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Buildium::BillPaymentLinePostMessage`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'bill_line_id') self.bill_line_id = attributes[:'bill_line_id'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end end |