Method: Buildium::LockPeriodSettingsGlobalMessage#initialize
- Defined in:
- lib/buildium-ruby/models/lock_period_settings_global_message.rb
#initialize(attributes = {}) ⇒ LockPeriodSettingsGlobalMessage
Initializes the object
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/buildium-ruby/models/lock_period_settings_global_message.rb', line 48 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Buildium::LockPeriodSettingsGlobalMessage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Buildium::LockPeriodSettingsGlobalMessage`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'lock_date') self.lock_date = attributes[:'lock_date'] end end |